//! Handle requests for a single author.

use std::sync::Arc;

use calibre_db::data::pagination::SortOrder;
use poem::{
    handler,
    web::{Data, Path},
    Response,
};

use crate::{app_state::AppState, data::book::Book, handlers::error::HandlerError, Accept};

/// Handle a request for an author with `id` and decide whether to render to html or OPDS.
#[handler]
pub async fn handler(
    id: Path<u64>,
    accept: Data<&Accept>,
    state: Data<&Arc<AppState>>,
) -> Result<Response, poem::Error> {
    let author = state
        .calibre
        .scalar_author(*id)
        .map_err(HandlerError::DataError)?;
    let books = state
        .calibre
        .author_books(*id, u32::MAX.into(), None, SortOrder::ASC)
        .map_err(HandlerError::DataError)?;
    let books = books
        .iter()
        .filter_map(|x| Book::full_book(x, &state))
        .collect::<Vec<Book>>();

    match accept.0 {
        Accept::Html => crate::handlers::html::author::handler(author, books).await,
        Accept::Opds => crate::handlers::opds::author::handler(author, books).await,
    }
}
