//! Handle requests for specific formats of a book.

use tokio::io::AsyncRead;

use poem::{Body, IntoResponse, Response};
use tokio_util::io::ReaderStream;

/// Handle a request for file.
///
/// Must not be used directly from a route as that makes it vulnerable to path traversal attacks.
pub async fn handler<A: AsyncRead + Send + 'static>(
    file_name: &str,
    reader: A,
    content_type: &str,
) -> Result<Response, poem::Error> {
    let stream = ReaderStream::new(reader);
    let body = Body::from_bytes_stream(stream);

    Ok(body
        .with_content_type(content_type)
        .with_header("Content-Disposition", format!("filename=\"{file_name}\""))
        .into_response())
}
