//! Handle multiple books in html.

use calibre_db::data::pagination::SortOrder;
use poem::Response;

use crate::{app_state::AppState, data::book::Book, handlers::paginated};

/// Render all books paginated by cursor in html.
pub async fn handler(
    state: &AppState,
    cursor: Option<&str>,
    sort_order: &SortOrder,
) -> Result<Response, poem::Error> {
    paginated::render(
        "books",
        || {
            state
                .calibre
                .books(25, cursor, sort_order)
                .map(|x| x.iter().filter_map(|y| Book::full_book(y, state)).collect())
        },
        |book| book.data.sort.clone(),
        |cursor| state.calibre.has_previous_books(cursor),
        |cursor| state.calibre.has_more_books(cursor),
    )
}
