//! Handle a single series in html.

use calibre_db::data::series::Series;
use poem::{error::InternalServerError, web::Html, IntoResponse, Response};
use tera::Context;

use crate::{data::book::Book, templates::TEMPLATES};

/// Render a single series as html.
pub async fn handler(series: Series, books: Vec<Book>) -> Result<Response, poem::Error> {
    let mut context = Context::new();
    context.insert("title", &series.name);
    context.insert("nav", "series");
    context.insert("books", &books);

    Ok(TEMPLATES
        .render("book_list", &context)
        .map_err(InternalServerError)
        .map(Html)?
        .into_response())
}
