//! Handle a single author for opds.

use calibre_db::data::author::Author;
use poem::{IntoResponse, Response};
use time::OffsetDateTime;

use crate::{
    data::book::Book,
    handlers::error::HandlerError,
    opds::{entry::Entry, feed::Feed, link::Link, media_type::MediaType, relation::Relation},
    APP_NAME,
};

/// Render a single author as an OPDS entry embedded in a feed.
pub async fn handler(author: Author, books: Vec<Book>) -> Result<Response, poem::Error> {
    let entries: Vec<Entry> = books.into_iter().map(Entry::from).collect();
    let now = OffsetDateTime::now_utc();

    let self_link = Link {
        href: format!("/opds/authors/{}", author.id),
        media_type: MediaType::Navigation,
        rel: Relation::Myself,
        title: None,
        count: None,
    };
    let feed = Feed::create(
        now,
        &format!("{APP_NAME}author:{}", author.id),
        &author.name,
        self_link,
        vec![],
        entries,
    );
    let xml = feed.as_xml().map_err(HandlerError::OpdsError)?;

    Ok(xml
        .with_content_type("application/atom+xml")
        .into_response())
}
