//! Handle recent books for OPDS.

use poem::{IntoResponse, Response};
use time::OffsetDateTime;

use crate::{
    data::book::Book,
    handlers::error::HandlerError,
    opds::{entry::Entry, feed::Feed, link::Link, media_type::MediaType, relation::Relation},
    APP_NAME,
};

/// Render recent books as OPDS entries embedded in a feed.
pub async fn handler(recent_books: Vec<Book>) -> Result<Response, poem::Error> {
    let entries: Vec<Entry> = recent_books.into_iter().map(Entry::from).collect();
    let now = OffsetDateTime::now_utc();

    let self_link = Link {
        href: "/opds/recent".to_string(),
        media_type: MediaType::Navigation,
        rel: Relation::Myself,
        title: None,
        count: None,
    };
    let feed = Feed::create(
        now,
        &format!("{APP_NAME}:recentbooks"),
        "Recent Books",
        self_link,
        vec![],
        entries,
    );
    let xml = feed.as_xml().map_err(HandlerError::OpdsError)?;

    Ok(xml
        .with_content_type("application/atom+xml")
        .into_response())
}
