//! Handle open search description..

use crate::{
    handlers::error::HandlerError,
    opds::search::{OpenSearchDescription, Url},
    APP_NAME,
};
use poem::{handler, IntoResponse, Response};

/// Render search information as open search description.
#[handler]
pub async fn handler() -> Result<Response, poem::Error> {
    let search = OpenSearchDescription {
        short_name: APP_NAME.to_string(),
        description: "Search for ebooks".to_string(),
        input_encoding: "UTF-8".to_string(),
        output_encoding: "UTF-8".to_string(),
        url: Url {
            type_name: "application/atom+xml".to_string(),
            template: "/opds/search?query={searchTerms}".to_string(),
        },
    };
    let xml = search.as_xml().map_err(HandlerError::OpdsError)?;
    Ok(xml
        .with_content_type("application/atom+xml")
        .into_response())
}
