//! Handle requests for recent books.

use std::sync::Arc;

use poem::{handler, web::Data, Response};

use crate::{app_state::AppState, data::book::Book, handlers::error::HandlerError, Accept};

/// Handle a request recent books and decide whether to render to html or OPDS.
#[handler]
pub async fn handler(
    accept: Data<&Accept>,
    state: Data<&Arc<AppState>>,
) -> Result<Response, poem::Error> {
    let recent_books = state
        .calibre
        .recent_books(25)
        .map_err(HandlerError::DataError)?;
    let recent_books = recent_books
        .iter()
        .filter_map(|x| Book::full_book(x, &state))
        .collect::<Vec<Book>>();

    match accept.0 {
        Accept::Html => crate::handlers::html::recent::handler(recent_books).await,
        Accept::Opds => crate::handlers::opds::recent::handler(recent_books).await,
    }
}
