//! Handle search requests.

use std::sync::Arc;

use poem::{
    handler,
    web::{Data, Query},
    Response,
};
use serde::Deserialize;

use crate::{app_state::AppState, data::book::Book, handlers::error::HandlerError, Accept};

#[derive(Deserialize)]
struct Params {
    /// Query for a search request.
    query: String,
}
/// Handle a search request with query parameter `query`.
#[handler]
pub async fn handler(
    accept: Data<&Accept>,
    state: Data<&Arc<AppState>>,
    Query(params): Query<Params>,
) -> Result<Response, poem::Error> {
    let books = state
        .calibre
        .search(&params.query)
        .map_err(HandlerError::DataError)?
        .iter()
        .filter_map(|book| Book::full_book(book, *state))
        .collect();

    match *accept {
        Accept::Html => crate::handlers::html::search::handler(books).await,
        Accept::Opds => crate::handlers::opds::search::handler(books).await,
    }
}
