//! Handle requests for multiple series.

use std::sync::Arc;

use calibre_db::data::pagination::SortOrder;
use poem::{
    handler,
    web::{Data, Path},
    Response,
};

use crate::{app_state::AppState, Accept};

/// Handle a request for multiple series, starting at the first.
#[handler]
pub async fn handler_init(
    accept: Data<&Accept>,
    state: Data<&Arc<AppState>>,
) -> Result<Response, poem::Error> {
    series(&accept, &state, None, &SortOrder::ASC).await
}

/// Handle a request for multiple series, starting at the `cursor` and going in the direction of
/// `sort_order`.
#[handler]
pub async fn handler(
    Path((cursor, sort_order)): Path<(String, SortOrder)>,
    accept: Data<&Accept>,
    state: Data<&Arc<AppState>>,
) -> Result<Response, poem::Error> {
    series(&accept, &state, Some(&cursor), &sort_order).await
}

async fn series(
    accept: &Accept,
    state: &Arc<AppState>,
    cursor: Option<&str>,
    sort_order: &SortOrder,
) -> Result<Response, poem::Error> {
    match accept {
        Accept::Html => {
            crate::handlers::html::series::handler(&state.calibre, cursor, sort_order).await
        }
        Accept::Opds => {
            crate::handlers::opds::series::handler(&state.calibre, cursor, sort_order).await
        }
    }
}
