//! Error handling for OPDS data.

use std::string::FromUtf8Error;

use quick_xml::DeError;
use thiserror::Error;

/// Errors happening during handling OPDS data.
#[derive(Error, Debug)]
#[error("opds error")]
pub enum OpdsError {
    /// Error serializing OPDS data.
    #[error("failed to serialize struct")]
    SerializingError(#[from] DeError),
    /// Error parsing OPDS xml structure.
    #[error("xml failure")]
    XmlError(#[from] quick_xml::Error),
    /// Error decoding xml as UTF-8.
    #[error("failed to decode as utf-8")]
    Utf8Error(#[from] FromUtf8Error),
}
